@@ -1,8 +1,9 @@
 /*
- * Copyright (C) 2005-2006 by Olivier Goffart <ogoffart at kde.org>
- */
+    SPDX-FileCopyrightText: 2005-2006 Olivier Goffart <ogoffart at kde.org>
+*/
+
+#include <KLocalizedString>
 #include <QApplication>
-#include <klocalizedstring.h>
 
 #include "knotifytestwindow.h"
 
